Learn R Programming

moexer (version 0.2.0)

query_iss: Submit a REST Query to ISS

Description

See http://iss.moex.com/iss/reference/ for the reference.

Usage

query_iss(
  rest_path,
  params = list(),
  iss_base_url = getOption("moexer.iss.base_url"),
  debug_output = getOption("moexer.debug"),
  follow_cursor = TRUE
)

Value

A list where every element is section as returned by ISS. The section content is parsed as a tibble.

Arguments

rest_path

A REST path concatenated to iss_base_url.

params

A HTTP GET query parameters string passed as a list.

iss_base_url

The base ISS URL.

debug_output

Print REST URLs as they are queried.

follow_cursor

If TRUE, iterative queries will be issued to fetch all section pages as indicated by <section>.cursor; the cursor section itself will be removed from the response.

Examples

Run this code
if (FALSE) {
query_iss(
    rest_path = 'securities/SBER',
    params = list(iss.only = 'description'),
    debug_output = TRUE
)
}

Run the code above in your browser using DataLab