powered by
REST path: /engines/[engine]/markets/[market]/boards/[board]/securities/[security]/candles (see http://iss.moex.com/iss/reference/46).
/engines/[engine]/markets/[market]/boards/[board]/securities/[security]/candles
get_candles(secid, from, till = NULL, interval = "monthly", ...)
A tibble as with candles in HLOCV format, plus a column with the corresponding security ID.
A vector of security ID's.
A lubridate::date object or a character that can be coerced to it.
A character value specifying the candle duration (see moexer.candle.intervals option.)
moexer.candle.intervals
Further arguments to query_iss.
To get the engine-market-board path a separate get_security_info query is made and the board with is_primary = 1 is selected.
engine-market-board
is_primary = 1
if (FALSE) { get_candles( secid = c('XXXX', 'SBER', 'FXGD'), from = '2020-01-01', debug = TRUE ) }
Run the code above in your browser using DataLab