A list where every element is section as returned by ISS. The
section content is parsed as a tibble.
Arguments
rest_path
A REST path concatenated to iss_base_url.
params
A HTTP GET query parameters string passed as a list.
iss_base_url
The base ISS URL.
debug_output
Print REST URLs as they are queried.
follow_cursor
If TRUE, iterative queries will be issued to fetch all
section pages as indicated by <section>.cursor; the cursor section
itself will be removed from the response.